##############################################################################
#
#    Xbus Common, for Odoo
#    Copyright © 2023, 2024 XCG Consulting <https://xcg-consulting.fr>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################
from odoo import models  # type: ignore[import-untyped]
from odoo.tests import TransactionCase  # type: ignore[import-untyped]
from odoo_test_helper import FakeModelLoader  # type: ignore[import-untyped]


class ModelCase(TransactionCase):
    """Test case used when temporary adding models to the registry."""

    @classmethod
    def import_test_models(cls) -> list[models.Model]:
        """Import the models used for tests.
        Can be inherited to change the imported models."""
        from .models import XbusMessage  # pylint: disable=import-outside-toplevel

        return [XbusMessage]

    @classmethod
    def setUpClass(cls):
        super().setUpClass()
        cls.loader = FakeModelLoader(cls.env, cls.__module__)
        cls.loader.backup_registry()
        # The import must be there, after the registry backup (see odoo-test-helper doc)
        model_list = cls.import_test_models()
        cls.loader.update_registry(model_list)

    @classmethod
    def tearDownClass(cls):
        cls.loader.restore_registry()
        super().tearDownClass()
